@@ -3,9 +3,9 @@ package Sah::Schema::date::day;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-12'; # DATE
+our $DATE = '2023-12-09'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 our $schema = [int => {
     summary => 'Day of month (1-31), e.g. 17',
@@ -35,7 +35,7 @@ Sah::Schema::date::day - Day of month (1-31), e.g. 17
 
 =head1 VERSION
 
-This document describes version 0.018 of Sah::Schema::date::day (from Perl distribution Sah-Schemas-Date), released on 2022-10-12.
+This document describes version 0.019 of Sah::Schema::date::day (from Perl distribution Sah-Schemas-Date), released on 2023-12-09.
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("date::day*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean result (true if data is valid, false if
+The above validator returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -65,27 +65,27 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = 1;
+ $data = 31;
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = 32;
- my $errmsg = $validator->($data); # => "Must be at most 31"
+ $data = "";
+ my $errmsg = $validator->($data); # => "Not of type integer"
 
-Often a schema has coercion rule or default value, so after validation the
-validated value is different. To return the validated (set-as-default, coerced,
-prefiltered) value:
+Often a schema has coercion rule or default value rules, so after validation the
+validated value will be different from the original. To return the validated
+(set-as-default, coerced, prefiltered) value:
 
  my $validator = gen_validator("date::day", {return_type=>'str_errmsg+val'});
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = 1;
- my $res = $validator->($data); # => ["",1]
+ $data = 31;
+ my $res = $validator->($data); # => ["",31]
  
  # a sample invalid data
- $data = 32;
- my $res = $validator->($data); # => ["Must be at most 31",32]
+ $data = "";
+ my $res = $validator->($data); # => ["Not of type integer",""]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -148,17 +148,30 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+=head2 Using on the CLI with validate-with-sah
+
+To validate some data on the CLI, you can use L<validate-with-sah> utility.
+Specify the schema as the first argument (encoded in Perl syntax) and the data
+to validate as the second argument (encoded in Perl syntax):
+
+ % validate-with-sah '"date::day*"' '"data..."'
+
+C<validate-with-sah> has several options for, e.g. validating multiple data,
+showing the generated validator code (Perl/JavaScript/etc), or loading
+schema/data from file. See its manpage for more details.
+
 
 =head2 Using with Type::Tiny
 
-To create a type constraint and type library from a schema:
+To create a type constraint and type library from a schema (requires
+L<Type::Tiny> as well as L<Type::FromSah>):
 
  package My::Types {
      use Type::Library -base;
      use Type::FromSah qw( sah2type );
 
      __PACKAGE__->add_type(
-         sah2type('$sch_name*', name=>'DateDay')
+         sah2type('date::day*', name=>'DateDay')
      );
  }
 
@@ -197,7 +210,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
