@@ -3,12 +3,12 @@ package Sah::Schema::date::month_name::en;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-12'; # DATE
+our $DATE = '2023-12-09'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 our $schema = [cistr => {
-    summary => 'Month name (abbreviated or full, in English), e.g. jan or "September"',
+    summary => 'Month name (abbreviated or full, in English), e.g. "jan" or "September"',
     in => [
         qw/jan feb mar apr may jun jul aug sep oct nov dec/,
         qw/january february march april june july august september october november december/,
@@ -35,7 +35,7 @@ _
 
 1;
 
-# ABSTRACT: Month name (abbreviated or full, in English), e.g. jan or "September"
+# ABSTRACT: Month name (abbreviated or full, in English), e.g. "jan" or "September"
 
 __END__
 
@@ -45,11 +45,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::month_name::en - Month name (abbreviated or full, in English), e.g. jan or "September"
+Sah::Schema::date::month_name::en - Month name (abbreviated or full, in English), e.g. "jan" or "September"
 
 =head1 VERSION
 
-This document describes version 0.018 of Sah::Schema::date::month_name::en (from Perl distribution Sah-Schemas-Date), released on 2022-10-12.
+This document describes version 0.019 of Sah::Schema::date::month_name::en (from Perl distribution Sah-Schemas-Date), released on 2023-12-09.
 
 =head1 SYNOPSIS
 
@@ -77,7 +77,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("date::month_name::en*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean result (true if data is valid, false if
+The above validator returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -89,12 +89,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "foo";
+ $data = 1;
  my $errmsg = $validator->($data); # => "Must be one of [\"jan\",\"feb\",\"mar\",\"apr\",\"may\",\"jun\",\"jul\",\"aug\",\"sep\",\"oct\",\"nov\",\"dec\",\"january\",\"february\",\"march\",\"april\",\"june\",\"july\",\"august\",\"september\",\"october\",\"november\",\"december\"]"
 
-Often a schema has coercion rule or default value, so after validation the
-validated value is different. To return the validated (set-as-default, coerced,
-prefiltered) value:
+Often a schema has coercion rule or default value rules, so after validation the
+validated value will be different from the original. To return the validated
+(set-as-default, coerced, prefiltered) value:
 
  my $validator = gen_validator("date::month_name::en", {return_type=>'str_errmsg+val'});
  my $res = $validator->($data); # [$errmsg, $validated_val]
@@ -104,8 +104,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["","FeB"]
  
  # a sample invalid data
- $data = "foo";
- my $res = $validator->($data); # => ["Must be one of [\"jan\",\"feb\",\"mar\",\"apr\",\"may\",\"jun\",\"jul\",\"aug\",\"sep\",\"oct\",\"nov\",\"dec\",\"january\",\"february\",\"march\",\"april\",\"june\",\"july\",\"august\",\"september\",\"october\",\"november\",\"december\"]","foo"]
+ $data = 1;
+ my $res = $validator->($data); # => ["Must be one of [\"jan\",\"feb\",\"mar\",\"apr\",\"may\",\"jun\",\"jul\",\"aug\",\"sep\",\"oct\",\"nov\",\"dec\",\"january\",\"february\",\"march\",\"april\",\"june\",\"july\",\"august\",\"september\",\"october\",\"november\",\"december\"]",1]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -168,17 +168,30 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+=head2 Using on the CLI with validate-with-sah
+
+To validate some data on the CLI, you can use L<validate-with-sah> utility.
+Specify the schema as the first argument (encoded in Perl syntax) and the data
+to validate as the second argument (encoded in Perl syntax):
+
+ % validate-with-sah '"date::month_name::en*"' '"data..."'
+
+C<validate-with-sah> has several options for, e.g. validating multiple data,
+showing the generated validator code (Perl/JavaScript/etc), or loading
+schema/data from file. See its manpage for more details.
+
 
 =head2 Using with Type::Tiny
 
-To create a type constraint and type library from a schema:
+To create a type constraint and type library from a schema (requires
+L<Type::Tiny> as well as L<Type::FromSah>):
 
  package My::Types {
      use Type::Library -base;
      use Type::FromSah qw( sah2type );
 
      __PACKAGE__->add_type(
-         sah2type('$sch_name*', name=>'DateMonthNameEn')
+         sah2type('date::month_name::en*', name=>'DateMonthNameEn')
      );
  }
 
@@ -225,7 +238,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
