@@ -3,12 +3,12 @@ package Sah::Schema::date::tz_name;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-12'; # DATE
+our $DATE = '2023-12-09'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 our $schema = [str => {
-    summary => 'Timezone name (validity not checked), e.g. Asia/Jakarta',
+    summary => 'Timezone name (validity not checked), e.g. "Asia/Jakarta"',
     description => <<'_',
 
 Currently no validation for valid timezone names. But completion is provided.
@@ -28,7 +28,7 @@ _
 
 1;
 
-# ABSTRACT: Timezone name (validity not checked), e.g. Asia/Jakarta
+# ABSTRACT: Timezone name (validity not checked), e.g. "Asia/Jakarta"
 
 __END__
 
@@ -38,11 +38,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::tz_name - Timezone name (validity not checked), e.g. Asia/Jakarta
+Sah::Schema::date::tz_name - Timezone name (validity not checked), e.g. "Asia/Jakarta"
 
 =head1 VERSION
 
-This document describes version 0.018 of Sah::Schema::date::tz_name (from Perl distribution Sah-Schemas-Date), released on 2022-10-12.
+This document describes version 0.019 of Sah::Schema::date::tz_name (from Perl distribution Sah-Schemas-Date), released on 2023-12-09.
 
 =head1 SYNOPSIS
 
@@ -58,7 +58,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("date::tz_name*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean result (true if data is valid, false if
+The above validator returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -69,9 +69,9 @@ valid, a non-empty error message otherwise):
  $data = "Asia/Jakarta";
  my $errmsg = $validator->($data); # => ""
 
-Often a schema has coercion rule or default value, so after validation the
-validated value is different. To return the validated (set-as-default, coerced,
-prefiltered) value:
+Often a schema has coercion rule or default value rules, so after validation the
+validated value will be different from the original. To return the validated
+(set-as-default, coerced, prefiltered) value:
 
  my $validator = gen_validator("date::tz_name", {return_type=>'str_errmsg+val'});
  my $res = $validator->($data); # [$errmsg, $validated_val]
@@ -141,17 +141,30 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+=head2 Using on the CLI with validate-with-sah
+
+To validate some data on the CLI, you can use L<validate-with-sah> utility.
+Specify the schema as the first argument (encoded in Perl syntax) and the data
+to validate as the second argument (encoded in Perl syntax):
+
+ % validate-with-sah '"date::tz_name*"' '"data..."'
+
+C<validate-with-sah> has several options for, e.g. validating multiple data,
+showing the generated validator code (Perl/JavaScript/etc), or loading
+schema/data from file. See its manpage for more details.
+
 
 =head2 Using with Type::Tiny
 
-To create a type constraint and type library from a schema:
+To create a type constraint and type library from a schema (requires
+L<Type::Tiny> as well as L<Type::FromSah>):
 
  package My::Types {
      use Type::Library -base;
      use Type::FromSah qw( sah2type );
 
      __PACKAGE__->add_type(
-         sah2type('$sch_name*', name=>'DateTzName')
+         sah2type('date::tz_name*', name=>'DateTzName')
      );
  }
 
@@ -194,7 +207,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
