@@ -3,12 +3,12 @@ package Sah::Schema::date::tz_offset_lax;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-12'; # DATE
+our $DATE = '2023-12-09'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 our $schema = ['date::tz_offset' => {
-    summary => 'Timezone offset in seconds from UTC (any offset is allowed, coercible from string), e.g. 1 or 25200 e.g. UTC+7',
+    summary => 'Timezone offset in seconds from UTC (any offset is allowed, coercible from string), e.g. 1 or 25200 e.g. "UTC+7"',
     'merge.delete.in' => [],
     min => -12*3600,
     max => +14*3600,
@@ -46,7 +46,7 @@ _
 
 1;
 
-# ABSTRACT: Timezone offset in seconds from UTC (any offset is allowed, coercible from string), e.g. 1 or 25200 e.g. UTC+7
+# ABSTRACT: Timezone offset in seconds from UTC (any offset is allowed, coercible from string), e.g. 1 or 25200 e.g. "UTC+7"
 
 __END__
 
@@ -56,11 +56,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::tz_offset_lax - Timezone offset in seconds from UTC (any offset is allowed, coercible from string), e.g. 1 or 25200 e.g. UTC+7
+Sah::Schema::date::tz_offset_lax - Timezone offset in seconds from UTC (any offset is allowed, coercible from string), e.g. 1 or 25200 e.g. "UTC+7"
 
 =head1 VERSION
 
-This document describes version 0.018 of Sah::Schema::date::tz_offset_lax (from Perl distribution Sah-Schemas-Date), released on 2022-10-12.
+This document describes version 0.019 of Sah::Schema::date::tz_offset_lax (from Perl distribution Sah-Schemas-Date), released on 2023-12-09.
 
 =head1 SYNOPSIS
 
@@ -98,7 +98,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("date::tz_offset_lax*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean result (true if data is valid, false if
+The above validator returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -106,23 +106,23 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "UTC+12:01";
+ $data = -1200;
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
  $data = "";
  my $errmsg = $validator->($data); # => "Cannot be empty"
 
-Often a schema has coercion rule or default value, so after validation the
-validated value is different. To return the validated (set-as-default, coerced,
-prefiltered) value:
+Often a schema has coercion rule or default value rules, so after validation the
+validated value will be different from the original. To return the validated
+(set-as-default, coerced, prefiltered) value:
 
  my $validator = gen_validator("date::tz_offset_lax", {return_type=>'str_errmsg+val'});
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "UTC+12:01";
- my $res = $validator->($data); # => ["",43260]
+ $data = -1200;
+ my $res = $validator->($data); # => ["",-43200]
  
  # a sample invalid data
  $data = "";
@@ -189,17 +189,30 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+=head2 Using on the CLI with validate-with-sah
+
+To validate some data on the CLI, you can use L<validate-with-sah> utility.
+Specify the schema as the first argument (encoded in Perl syntax) and the data
+to validate as the second argument (encoded in Perl syntax):
+
+ % validate-with-sah '"date::tz_offset_lax*"' '"data..."'
+
+C<validate-with-sah> has several options for, e.g. validating multiple data,
+showing the generated validator code (Perl/JavaScript/etc), or loading
+schema/data from file. See its manpage for more details.
+
 
 =head2 Using with Type::Tiny
 
-To create a type constraint and type library from a schema:
+To create a type constraint and type library from a schema (requires
+L<Type::Tiny> as well as L<Type::FromSah>):
 
  package My::Types {
      use Type::Library -base;
      use Type::FromSah qw( sah2type );
 
      __PACKAGE__->add_type(
-         sah2type('$sch_name*', name=>'DateTzOffsetLax')
+         sah2type('date::tz_offset_lax*', name=>'DateTzOffsetLax')
      );
  }
 
@@ -253,7 +266,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
